@@ -3,19 +3,18 @@ from __future__ import annotations
 
 import logging
 import json
+
 from typing import Any
 
 import ckan.plugins as p
-import ckan.plugins.toolkit as tk
 from ckan.lib.search.query import QUERY_FIELDS
 
 import ckanext.resource_indexer.interface as interface
 import ckanext.resource_indexer.utils as utils
 
-log = logging.getLogger(__name__)
+from . import config
 
-CONFIG_JSON_AS_TEXT = "ckanext.resoruce_indexer.json.add_as_plain"
-DEFAULT_JSON_AS_TEXT = False
+log = logging.getLogger(__name__)
 
 
 class ResourceIndexerPlugin(p.SingletonPlugin):
@@ -24,10 +23,12 @@ class ResourceIndexerPlugin(p.SingletonPlugin):
     # IPackageController
 
     def before_dataset_index(self, pkg_dict):
+        if utils.bypass_indexation():
+            return pkg_dict
+
         resources = json.loads(pkg_dict["validated_data_dict"]).get(
             "resources", []
         )
-
         for res in utils.select_indexable_resources(resources):
             utils.index_resource(res, pkg_dict)
         return pkg_dict
@@ -80,16 +81,20 @@ class JsonResourceIndexerPlugin(p.SingletonPlugin):
     p.implements(interface.IResourceIndexer)
 
     def get_resource_indexer_weight(self, res: dict[str, Any]) -> int:
-        fmt = res['format'].lower()
-        if fmt == 'json':
+        fmt = res["format"].lower()
+        if fmt == "json":
             return utils.Weight.default
         return utils.Weight.skip
 
     def extract_indexable_chunks(self, path: str) -> dict[str, Any]:
         return utils.extract_json(path)
 
-    def merge_chunks_into_index(self, pkg_dict: dict[str, Any], chunks: dict[str, Any]):
+    def merge_chunks_into_index(
+        self, pkg_dict: dict[str, Any], chunks: dict[str, Any]
+    ):
         pkg_dict.update(chunks)
 
-        if tk.config.get(CONFIG_JSON_AS_TEXT, DEFAULT_JSON_AS_TEXT):
-            utils.merge_text_chunks(pkg_dict, [f" {k}: {v}" for k, v in chunks.items()])
+        if config.index_json_as_text():
+            utils.merge_text_chunks(
+                pkg_dict, [f" {k}: {v}" for k, v in chunks.items()]
+            )
