@@ -5,38 +5,18 @@ import os
 import tempfile
 import enum
 import json
-from typing import Any, Iterable, Optional, TypeVar
+from typing import Any, Iterable, Optional
 
 import requests
-from werkzeug.utils import import_string
 
 import ckan.plugins as p
-import ckan.plugins.toolkit as tk
 from ckan.lib.uploader import get_resource_uploader
 
-TResourceDict = TypeVar("TResourceDict", bound="dict[str, Any]")
+from . import config
+
 
 log = logging.getLogger(__name__)
 
-CONFIG_INDEX_FIELD = "ckanext.resoruce_indexer.index_field"
-CONFIG_MAX_REMOTE_SIZE = "ckanext.resource_indexer.max_remote_size"
-CONFIG_ALLOW_REMOTE = "ckanext.resource_indexer.allow_remote"
-CONFIG_INDEXABLE_FORMATS = "ckanext.resource_indexer.indexable_formats"
-CONFIG_BOOST = "ckanext.resoruce_indexer.search_boost"
-CONFIG_JSON_KEY = "ckanext.resoruce_indexer.json.key_processor"
-CONFIG_JSON_VALUE = "ckanext.resoruce_indexer.json.value_processor"
-
-
-
-
-DEFAULT_INDEX_FIELD = None
-DEFAULT_MAX_REMOTE_SIZE = 4
-DEFAULT_ALLOW_REMOTE = False
-DEFAULT_INDEXABLE_FORMATS = None
-DEFAULT_BOOST = 1.0
-DEFAULT_JSON_KEY = "builtins:str"
-DEFAULT_JSON_VALUE = "builtins:str"
-
 
 class Weight(enum.IntEnum):
     skip = 0
@@ -47,22 +27,25 @@ class Weight(enum.IntEnum):
     override = 50
 
 
-def select_indexable_resources(resources: Iterable[TResourceDict]) -> Iterable[TResourceDict]:
+def select_indexable_resources(
+    resources: Iterable[dict[str, Any]],
+) -> Iterable[dict[str, Any]]:
     """Select resources that supports indexation.
 
     Returns:
         indexable resources
 
     """
-    supported = tk.aslist(
-        tk.config.get(CONFIG_INDEXABLE_FORMATS, DEFAULT_INDEXABLE_FORMATS)
-    )
+    supported = config.indexable_formats()
     for res in resources:
         if res.get("format", "").lower() in supported:
             yield res
 
 
 def index_resource(res: dict[str, Any], pkg_dict: dict[str, Any]):
+    """Extract the data from resource and merge it into the package.
+
+    """
     removable_path = _get_removable_filepath_for_resource(res)
     if not removable_path:
         return
@@ -80,11 +63,12 @@ def index_resource(res: dict[str, Any], pkg_dict: dict[str, Any]):
 
 
 def _get_handler(res):
-    """
-    Handler is a plugin that will provide as with method to index resource
-    Based on Weight we are returning the most valuable one
+    """Handler is a plugin that provides a method to index resource.
+
+    Based on Weight we are returning the most valuable one.
     """
     from ckanext.resource_indexer.interface import IResourceIndexer
+
     handlers = [
         plugin
         for (weight, plugin) in sorted(
@@ -92,15 +76,17 @@ def _get_handler(res):
                 (plugin.get_resource_indexer_weight(res), plugin)
                 for plugin in p.PluginImplementations(IResourceIndexer)
             ],
-            key=lambda pair: pair[0]
+            key=lambda pair: pair[0],
         )
-        if plugin and weight > 0
+        if plugin and weight > Weight.skip
     ]
 
     return handlers[-1] if handlers else None
 
 
 class StaticPath:
+    """With-context for a filepath that should not be modified.
+    """
     def __init__(self, path: Optional[str]):
         self.path = path
 
@@ -115,13 +101,34 @@ class StaticPath:
 
 
 class RemovablePath(StaticPath):
+    """With-context for a filepath that must be removed on exit.
+
+    Use it for temporarily downloaded files.
+    """
+
     def __exit__(self, type, value, traceback):
         if self.path:
             os.remove(self.path)
 
 
-def _get_removable_filepath_for_resource(res) -> Optional[StaticPath]:
-    """Returns a filepath for a resource that will be indexed"""
+def _get_removable_filepath_for_resource(res: dict[str, Any]) -> Optional[StaticPath]:
+    """Returns a context with a path to the file owned by the resource.
+
+    The real path can be extracted from the return value using with-statement:
+
+        >>> result = _get_removable_filepath_for_resource(res)
+        >>> if not result:
+        >>>     return
+        >>> with result as path:
+        >>>     do_something_with_path(path)
+
+    If resource contains a link to the remote file(or uploaded via cloudstorage
+    plugin), this file can be downloaded, depending on configuration. After
+    processing, file will be automatically removed.
+
+
+
+    """
     res_id = res["id"]
     res_url = res["url"]
 
@@ -130,7 +137,7 @@ def _get_removable_filepath_for_resource(res) -> Optional[StaticPath]:
 
         # TODO temporary workaround for ckanext-cloudstorage support
         if p.plugin_loaded("cloudstorage"):
-            url = uploader.get_url_from_filename(res_id, res_url)
+            url = uploader.get_url_from_filename(res_id, res_url)  # type: ignore
             filepath = _download_remote_file(res_id, url)
             return RemovablePath(filepath)
 
@@ -141,7 +148,7 @@ def _get_removable_filepath_for_resource(res) -> Optional[StaticPath]:
 
         return StaticPath(path)
 
-    if not tk.asbool(tk.config.get(CONFIG_ALLOW_REMOTE, DEFAULT_ALLOW_REMOTE)):
+    if not config.allow_remote():
         return
 
     filepath = _download_remote_file(res_id, res_url)
@@ -176,7 +183,6 @@ def _download_remote_file(res_id: str, url: str) -> Optional[str]:
         log.warn("Incorrect Content-length header from url <{}>".format(url))
         return
 
-
     if 0 < size < _get_remote_res_max_size():
         dest = tempfile.NamedTemporaryFile(delete=False)
         try:
@@ -195,16 +201,11 @@ def _download_remote_file(res_id: str, url: str) -> Optional[str]:
 
 
 def _get_remote_res_max_size():
-    return (
-        tk.asint(
-            tk.config.get(CONFIG_MAX_REMOTE_SIZE, DEFAULT_MAX_REMOTE_SIZE)
-        )
-        * 1024 ** 2
-    )
+    return config.max_remote_size() * 1024**2
 
 
 def merge_text_chunks(pkg_dict, chunks):
-    index_field = tk.config.get(CONFIG_INDEX_FIELD, DEFAULT_INDEX_FIELD)
+    index_field = config.index_field()
     if index_field:
         str_index = "".join(map(str, chunks))
         if str_index:
@@ -254,25 +255,28 @@ def extract_json(path) -> dict[str, Any]:
             log.exception("Cannot index JSON resource at %s", path)
             return {}
 
-    key = import_string(tk.config.get(CONFIG_JSON_KEY, DEFAULT_JSON_KEY))
-    value = import_string(tk.config.get(CONFIG_JSON_VALUE, DEFAULT_JSON_VALUE))
+    key = config.json_key()
+    value = config.json_value()
 
-    return {
-        key(k): value(v)
-        for k, v in data.items()
-    }
+    return {key(k): value(v) for k, v in data.items()}
 
 
 def get_boost_string():
-    field = tk.config.get(CONFIG_INDEX_FIELD, DEFAULT_INDEX_FIELD)
-    try:
-        boost = float(tk.config.get(CONFIG_BOOST, DEFAULT_BOOST))
-    except (TypeError, ValueError) as e:
-        log.error("Cannot parse %s: %s", CONFIG_BOOST, e)
-        boost = DEFAULT_BOOST
+    field = config.index_field()
+
+    boost = config.boost()
+
     if not field or boost == 1:
         return
     if boost.is_integer():
         boost = int(boost)
 
     return f"{field}^{boost}"
+
+
+def bypass_indexation() -> bool:
+    """Check if indexation is disabled.
+
+    May be used for fast index re-builds.
+    """
+    return bool(os.getenv("CKANEXT_RESOURCE_INDEXER_BYPASS"))
